==> qirt-1.1.1.tar.gz: qirt-1.1.1/docs/index.md <==
# Welcome to Quantum Information Research Toolkit Documentation

Welcome to the documentation for the Quantum Information Research Toolkit (QIRT), your comprehensive guide to leveraging quantum computing for research and development. This toolkit provides various functionalities to help you create, simulate, and analyze quantum circuits and states.

## Documentation overview

1. **[Tutorials](tutorials)**
    - Learn the basics usage of QIRT with hands-on examples.
2. **[How-To Guides](how_to_guides)**
    - Step-by-step instructions for specific tasks and use cases.
3. **[Reference](reference)**
    - Detailed descriptions of all QIRT functions, classes, and modules.

## Getting started

If you're new to QIRT, we recommend starting with our [Tutorials](tutorials.md) to get an overview of the toolkit's capabilities and how to use them effectively.

For specific tasks or problems, check out our [How-To Guides](how-to-guides.md). These guides provide practical solutions and examples for common use cases.

Finally, our [Reference](reference.md) section offers in-depth documentation on all available functions, classes, and modules within QIRT. Use this section as a technical resource for detailed information on QIRT's API.

## About QIRT

The Quantum Information Research Toolkit is designed to support researchers, educators, and developers working in the field of quantum information. Our goal is to provide researchers with a convenient computational tool to facilitate research and development in quantum computing. QIRT is built on top of Qiskit, a widely-used quantum computing framework, and provides additional functionalities to enhance your quantum computing experience.

---

Thank you for using the Quantum Information Research Toolkit. We hope you find it valuable in your quantum computing endeavors.

==> qirt-1.1.3.tar.gz: qirt-1.1.3/docs/index.md <==
---
hide:
  - navigation
---

# Welcome to Quantum Information Research Toolkit Documentation

Welcome to the documentation for the Quantum Information Research Toolkit (QIRT), your comprehensive guide to leveraging quantum computing for research and development. This toolkit provides various functionalities to help you create, simulate, and analyze quantum circuits and states.

## Documentation overview

1. **[Tutorials](tutorials/index.md)**
    - Learn the basics usage of QIRT with hands-on examples.
2. **[How-To Guides](how_to_guides/index.md)**
    - Step-by-step instructions for specific tasks and use cases.
3. **[Reference](reference/index.md)**
    - Detailed descriptions of all QIRT functions, classes, and modules.

## Getting started

If you're new to QIRT, we recommend starting with our [Tutorials](tutorials/index.md) to get an overview of the toolkit's capabilities and how to use them effectively.

For specific tasks or problems, check out our [How-To Guides](how_to_guides/index.md). These guides provide practical solutions and examples for common use cases.

Finally, our [Reference](reference/index.md) section offers in-depth documentation on all available functions, classes, and modules within QIRT. Use this section as a technical resource for detailed information on QIRT's API.

## About QIRT

The Quantum Information Research Toolkit is designed to support researchers, educators, and developers working in the field of quantum information. Our goal is to provide researchers with a convenient computational tool to facilitate research and development in quantum computing. QIRT is built on top of Qiskit, a widely-used quantum computing framework, and provides additional functionalities to enhance your quantum computing experience.

---

Thank you for using the Quantum Information Research Toolkit. We hope you find it valuable in your quantum computing endeavors.
